@@ -16,7 +16,7 @@ function (object, mt = " ", st = " ", cpt = " ", blind.label=FALSE, cc = NULL, c
      print("The Call from this database is")
      print(MC)
      analysis <- substr(MC,start=11, stop=13)[1]
-     if(!any(analysis==c("lm","lme","glm","cph"))){
+     if(!any(analysis==c("lm","lme","glm","cph","nls"))){
           Hmisc::prn(analysis)
           stop("Call does not indicate a recognized underlying analysis function")
      }
@@ -69,6 +69,26 @@ function (object, mt = " ", st = " ", cpt = " ", blind.label=FALSE, cc = NULL, c
           print(search.history(object))
      }
 
+     if(analysis=="nls"){
+#          plotdiag.AICX(object, maintitle = mt, subtitle = st, caption = cpt, wmf="AICX", Cairo=Cairo)
+#          plotdiag.Cook(object, maintitle = mt, subtitle = st, caption = cpt, wmf="Cook", Cairo=Cairo)  
+#          plotdiag.deviance.residuals(object, maintitle = mt, subtitle = st, caption = cpt, wmf="Deviance residuals", Cairo=Cairo)
+#          plotdiag.deviances(object, maintitle = mt, subtitle = st, caption = cpt, wmf="Deviances", Cairo=Cairo)
+#          plotdiag.fit3(object, maintitle = mt, subtitle = st, caption = cpt, wmf="fit3", Cairo=Cairo)
+#          plotdiag.leverage(object, maintitle = mt, subtitle = st, caption = cpt, wmf="leverage", Cairo=Cairo)         
+          plotdiag.params.fixed(object, coeff.codenums=cc, maintitle = mt, subtitle = st, caption = cpt, wmf="params fixed", Cairo=Cairo)
+#          plotdiag.params.random(object, coeff.codenums=ccrand, maintitle = mt, subtitle = st, caption = cpt, wmf="params random"
+#          plotdiag.phihatx(object, maintitle = mt, subtitle = st, caption = cpt, wmf="phihatx", Cairo=Cairo)
+          plotdiag.residuals(object, maintitle = mt, subtitle = st, caption = cpt, wmf="residuals", Cairo=Cairo)         
+          plotdiag.s2(object, maintitle = mt, subtitle = st, caption = cpt, wmf="s2", Cairo=Cairo)
+          plotdiag.tstats(object, maintitle = mt, subtitle = st, caption = cpt, wmf="tstats", Cairo=Cairo)  
+#          plotdiag.ANOX2(object, anova.rows=NULL, ylab.extend="v",  maintitle = mt, subtitle = st, caption = cpt, wmf="anova", Cairo=Cairo)
+
+
+          Hmisc::prn(names(object))
+          print(search.history(object))
+     }
+
      if(analysis=="lme"){
 #          plotdiag.AICX(object, maintitle = mt, subtitle = st, caption = cpt, wmf="AICX", Cairo=Cairo)
           plotdiag.Cook(object, maintitle = mt, subtitle = st, caption = cpt, wmf="Cook", Cairo=Cairo)  
